@@ -1,13 +1,10 @@
-#!/bin/sh
-# tricking... the line after a these comments are interpreted as standard shell script \
-    exec $ESPRESSO_SOURCE/Espresso $0 $*
 #############################################################
 #                                                           #
 #  Lennard Jones Liquid                                     #
 #                                                           #
 #############################################################
 #
-# Copyright (C) 2010,2012,2013 The ESPResSo project
+# Copyright (C) 2010,2012,2013,2014 The ESPResSo project
 # Copyright (C) 2002,2003,2004,2005,2006,2007,2008,2009,2010 
 #   Max-Planck-Institute for Polymer Research, Theory Group
 #  
@@ -59,7 +56,6 @@ set density 0.7
 set lj1_eps     1.0
 set lj1_sig     1.0
 set lj1_cut     1.12246
-set lj1_shift   [calc_lj_shift $lj1_sig $lj1_cut]
 
 # Integration parameters
 #############################################################
@@ -91,7 +87,7 @@ set tcl_precision 6
 
 setmd box_l $box_l $box_l $box_l
 
-inter 0 0 lennard-jones $lj1_eps $lj1_sig $lj1_cut $lj1_shift 0
+inter 0 0 lennard-jones $lj1_eps $lj1_sig $lj1_cut auto
 
 # Particle setup
 #############################################################
@@ -129,7 +125,8 @@ if { $vmd_output=="yes" } {
 #open Observable file
 set obs_file [open "$name$ident.obs" "w"]
 puts $obs_file "\# System: $name$ident"
-puts $obs_file "\# Time\tE_tot\tE_kin\t..."
+puts $obs_file "\# Time\tE_tot\tE_kin\tE_LJ"
+flush $obs_file
 
 puts "\nStart warmup integration:"
 puts "At maximum $warm_n_times times $warm_steps steps"
@@ -137,7 +134,7 @@ puts "Stop if minimal distance is larger than $min_dist"
 
 # set LJ cap
 set cap 20
-inter ljforcecap $cap
+inter forcecap $cap
 
 # Warmup Integration Loop
 set i 0
@@ -150,15 +147,15 @@ while { $i < $warm_n_times && $act_min_dist < $min_dist } {
 
     # Warmup criterion
     set act_min_dist [analyze mindist]
-    puts -nonewline "run $i at time=[setmd time] (LJ cap=$cap) min dist = $act_min_dist\r"
+    puts "run $i at time=[setmd time] (LJ cap=$cap) min dist = $act_min_dist\r"
     flush stdout
 
 #   write observables
-    puts $obs_file "{ time [setmd time] } [analyze energy]"
+    puts $obs_file "[setmd time] [analyze energy total] [analyze energy kinetic] [analyze energy nonbonded 0 0]"
 
 #   Increase LJ cap
     set cap [expr $cap+10]
-    inter ljforcecap $cap
+    inter forcecap $cap
     incr i
 }
 
@@ -178,41 +175,49 @@ puts "periodicity   [setmd periodicity]"
 puts "transfer_rate [setmd transfer_rate]" 
 puts "verlet_reuse  [setmd verlet_reuse]" 
 
-# write parameter file
-polyBlockWrite "$name$ident.set" {box_l time_step skin} "" 
+# write configurations file
+set trajectory [open "$name$ident.config" "w"]
+
+blockfile $trajectory write variable {box_l time_step skin}
+blockfile $trajectory write interactions
+blockfile $trajectory write integrate
+blockfile $trajectory write thermostat
+flush $trajectory
 
 #############################################################
 #      Integration                                          #
 #############################################################
 puts "\nStart integration: run $int_n_times times $int_steps steps"
 
-inter ljforcecap 0
+inter forcecap 0
 
 puts [analyze energy]
 
 set j 0
 for {set i 0} { $i < $int_n_times } { incr i} {
-
-
     puts -nonewline "run $i at time=[setmd time] "
 
     integrate $int_steps
     if { $vmd_output=="yes" } { imd positions }
 #   write observables
     set energies [analyze energy]
-    puts $obs_file "{ time [setmd time] } $energies"
+    puts $obs_file "[setmd time] [analyze energy total] [analyze energy kinetic] [analyze energy nonbonded 0 0]"
+    flush $obs_file
     puts -nonewline "temp = [expr [lindex $energies 1 1]/(([degrees_of_freedom]/2.0)*[setmd n_part])]\r"
     flush stdout
 
 #   write intermediate configuration
     if { $i%10==0 } {
-	polyBlockWrite "$name$ident.[format %04d $j]" {time box_l} {id pos type}
+	blockfile $trajectory write particles
+	flush $trajectory
 	incr j
     }
 }
 
 # write end configuration
-polyBlockWrite "$name$ident.end" {time box_l} {id pos type}
+blockfile $trajectory write particles
+blockfile $trajectory write variable { time }
+close $trajectory
 
 close $obs_file
 
