@@ -1,13 +1,10 @@
-#!/bin/sh
-# tricking... the line after a these comments are interpreted as standard shell script \
-    exec $ESPRESSO_SOURCE/Espresso $0 $*
 #############################################################
 #                                                           #
 #  ESPResSo Tutorial                                        #
 #                                                           #
 #############################################################
 #
-# Copyright (C) 2010,2012,2013 The ESPResSo project
+# Copyright (C) 2010,2012,2013,2014 The ESPResSo project
 # Copyright (C) 2002,2003,2004,2005,2006,2007,2008,2009,2010 
 #   Max-Planck-Institute for Polymer Research, Theory Group
 #  
@@ -211,12 +208,7 @@ if { $vmd == "yes" } {
 # This calls a small tcl script which starts the program    #
 # VMD and opens a socket connection between ESPResSo and    #
 # VMD.                                                      #
-    prepare_vmd_connection tutorial 3000
-
-# Just wait a moment until VMD has started.                 #
-# The 'exec' command is quite useful since with that you can#
-# call any other program from within your simulation script.#
-    exec sleep 4
+    prepare_vmd_connection tutorial start wait 3000
 
 # The additional command imd steers the socket connection   #
 # to VMD, e.g. sending the actual coordinates               #
@@ -230,7 +222,7 @@ if { $vmd == "yes" } {
 # of the Lennard-Jones interaction.                         #
 #                                                           #
 # To avoid this singularity ESPResSo offers the             #
-# possibility to cap potentials. Look at the 'ljforcecap'   #
+# possibility to cap potentials. Look at the 'forcecap'     #
 # option of the 'inter' command. We start with a value of   #
 # 10 for the cap and increase it step wise.                 #
 #                                                           #
@@ -251,8 +243,8 @@ if { $vmd == "yes" } {
 set min 0
 set cap 10
 while { $min < 0.8 } {
-    # set ljforcecap
-    inter ljforcecap $cap
+    # set forcecap
+    inter forcecap $cap
     # integrate a number of steps, e.g. 20
     integrate 20
     # check the status of the sytem
@@ -261,9 +253,9 @@ while { $min < 0.8 } {
     incr cap 10
 }
 puts "Warmup finished. Minimal distance now $min"
-# turn off the ljforcecap, which is done by setting the 
+# turn off the forcecap, which is done by setting the 
 # force cap value to zero:
-inter ljforcecap 0
+inter forcecap 0
 
 
 #############################################################
@@ -360,8 +352,11 @@ close $obs
 # Uncommenting the following two lines will show
 # you a plot of the rg values
 #plotObs "rg.dat" { 1:2 } labels { "time" "rg" } out "rg"
+# The 'exec' command is quite useful since with that you can#
+# call any other program from within your simulation script.#
 #exec gv rg.ps
 
+
 #############################################################
 #                                                           #
 # CONGRATULATIONS !!!                                       #
