@@ -1,4 +1,4 @@
-# Copyright (C) 2010,2011,2012,2013 The ESPResSo project
+# Copyright (C) 2010,2011,2012,2013,2014 The ESPResSo project
 # Copyright (C) 2002,2003,2004,2005,2006,2007,2008,2009,2010 
 #   Max-Planck-Institute for Polymer Research, Theory Group
 #  
@@ -30,7 +30,6 @@ source "tests_common.tcl"
 
 require_feature "LB_GPU"
 require_feature "LENNARD_JONES"
-require_feature "ADRESS" off
 
 puts "----------------------------------------"
 puts "- Testcase lb_gpu.tcl running on [format %02d [setmd n_nodes]] nodes  -"
@@ -114,8 +113,19 @@ thermostat off
 
 # Fluid
 #############################################################
-lbfluid gpu dens $dens visc $viscosity agrid $agrid tau $tau
-lbfluid friction $friction
+
+set components [setmd lb_components]
+if {$components==1} {
+  lbfluid gpu agrid $agrid dens $dens visc $viscosity agrid $agrid tau $tau \
+              friction $friction
+}
+if {$components==2} {
+  lbfluid gpu agrid $agrid dens $dens $dens visc $viscosity $viscosity agrid $agrid tau $tau sc_coupling 0.0 0.0 0.0 \
+              friction $friction $friction
+  exit 0
+}
+
+
 
 thermostat lb $temp
 
